=======
History
=======

1.0.0 (2019-05-20)
------------------

* First release on PyPI.

1.2.0 (2019-05-20)
------------------

* Add simulation progress bar as a default feature.
* Add cystein disulfide bond modification of topologie.

